@@ -14,7 +14,7 @@ import (
 var jsonnetImpl = &goimpl.JsonnetGoImplementation{}
 
 func TestResolvePrecedence(t *testing.T) {
-	s, err := jsonnet.EvaluateFile(jsonnetImpl, "./testdata/precedence/environments/default/main.jsonnet", jsonnet.Opts{})
+	s, err := jsonnet.EvaluateFile(t.Context(), jsonnetImpl, "./testdata/precedence/environments/default/main.jsonnet", jsonnet.Opts{})
 	require.NoError(t, err)
 
 	want := map[string]string{
