@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strings"
 	"testing"
 
 	"github.com/grafana/tanka/pkg/jsonnet"
@@ -141,6 +142,12 @@ func TestExportEnvironments(t *testing.T) {
     "static/updated-again-deployment.yaml": "test-export-envs/static-env/main.jsonnet",
     "static/updated-again-service.yaml": "test-export-envs/static-env/main.jsonnet"
 }`)
+
+	// Finally make sure that the indentation is 2 spaces by looking at `metadata.name`
+	deploymentRawContent, err := os.ReadFile(filepath.Join(tempDir, "static", "updated-again-deployment.yaml"))
+	require.NoError(t, err)
+	deploymentContent := strings.Split(string(deploymentRawContent), "\n")
+	require.Contains(t, deploymentContent, "  name: updated-again-deployment", "file indentation is most likely no longer 2 spaces")
 }
 
 func TestExportEnvironmentsBroken(t *testing.T) {
@@ -192,6 +199,45 @@ func BenchmarkExportEnvironmentsWithReplaceEnvs(b *testing.B) {
 	}
 }
 
+func TestExportEnvironmentsSkipManifest(t *testing.T) {
+	tempDir := t.TempDir()
+	require.NoError(t, os.Chdir("testdata"))
+	defer func() { require.NoError(t, os.Chdir("..")) }()
+
+	// Find envs
+	envs, err := FindEnvs(t.Context(), "test-export-envs", FindOpts{Selector: labels.Everything()})
+	require.NoError(t, err)
+
+	// Export all envs with skip manifest flag
+	opts := &ExportEnvOpts{
+		Format:       "{{.metadata.namespace}}/{{.metadata.name}}",
+		Extension:    "yaml",
+		SkipManifest: true,
+	}
+	opts.Opts.ExtCode = jsonnet.InjectedCode{
+		"deploymentName": "'test-deployment'",
+		"serviceName":    "'test-service'",
+	}
+	require.NoError(t, ExportEnvironments(t.Context(), envs, tempDir, opts))
+
+	// Check that all manifest files are created but manifest.json is NOT created
+	expectedFiles := []string{
+		filepath.Join(tempDir, "inline-namespace1", "my-configmap.yaml"),
+		filepath.Join(tempDir, "inline-namespace1", "my-deployment.yaml"),
+		filepath.Join(tempDir, "inline-namespace1", "my-service.yaml"),
+		filepath.Join(tempDir, "inline-namespace2", "my-deployment.yaml"),
+		filepath.Join(tempDir, "inline-namespace2", "my-service.yaml"),
+		filepath.Join(tempDir, "static", "test-deployment.yaml"),
+		filepath.Join(tempDir, "static", "test-service.yaml"),
+	}
+	checkFiles(t, tempDir, expectedFiles)
+
+	// Explicitly verify manifest.json does not exist
+	manifestPath := filepath.Join(tempDir, "manifest.json")
+	_, err = os.Stat(manifestPath)
+	assert.True(t, os.IsNotExist(err), "manifest.json should not exist when SkipManifest is true")
+}
+
 func checkFiles(t testing.TB, dir string, files []string) {
 	t.Helper()
 
